use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Tatsuhiko
Miyagawa
miyagawa
Kevin
Ryde
kryde
Marcel
Grünauer
marcel
Mike
Doherty
doherty
Patrice
Clement
monsieurp
Zoffix
Znet
zoffix
lib
Test
Synopsis
